@@ -109,6 +109,26 @@ class CollectionTestCase(unittest.TestCase):
 
         Collection.remove(name=collection_name)
 
+    def test_different_document_revisions(self):
+
+        collection_name = 'test_revision_documents'
+
+        col = Collection.create(name=collection_name)
+        doc1 = col.create_document()
+        doc1.save()
+
+        all_documents = col.documents()
+        self.assertEqual(len(all_documents), 1)
+        doc = all_documents[0]
+
+        self.assertEqual(doc.revision, doc1.revision)
+
+        doc.foo = 'bar'
+        doc.save()
+
+        self.assertNotEqual(doc.revision, doc1.revision)
+
+        Collection.remove(name=collection_name)
 
 class DocumentTestCase(unittest.TestCase):
     def setUp(self):
